@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Measure the emotional sentiment of text
 
-our $VERSION = '0.0601';
+our $VERSION = '0.07';
 
 use Moo;
 use strictures 2;
@@ -141,6 +141,32 @@ sub nrc_sentiment {
     $self->nrc_scores( \@scores );
 }
 
+
+sub get_word {
+    my ( $self, $word ) = @_;
+
+    my $positive = Lingua::EN::Opinion::Positive->new();
+    my $negative = Lingua::EN::Opinion::Negative->new();
+
+    return exists $positive->wordlist->{$word} || exists $negative->wordlist->{$word}
+        ? {
+            positive => exists $positive->wordlist->{$word} ? 1 : 0,
+            negative => exists $negative->wordlist->{$word} ? 1 : 0,
+        }
+        : undef;
+}
+
+
+sub nrc_get_word {
+    my ( $self, $word ) = @_;
+
+    my $emotion = Lingua::EN::Opinion::Emotion->new();
+
+    return exists $emotion->wordlist->{$word}
+        ? $emotion->wordlist->{$word}
+        : undef;
+}
+
 1;
 
 __END__
@@ -155,7 +181,7 @@ Lingua::EN::Opinion - Measure the emotional sentiment of text
 
 =head1 VERSION
 
-version 0.0601
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -172,8 +198,7 @@ version 0.0601
 
 A C<Lingua::EN::Opinion> measures the emotional sentiment of text.
 
-NOTE: This module is over 3MB uncompressed because of the GIANT sentiment text
-it comes with.
+* This module is large because of the GIANT sentiment text it comes with.
 
 Please see the F<eg/> and F<t/> scripts for example usage.
 
@@ -249,6 +274,20 @@ This is given by a 0/1 list of these 10 emotional elements:
 
 This method sets the B<nrc_scores> and B<sentences> attributes.
 
+=head2 get_word()
+
+  $sentiment = $opinion->get_word($word);
+
+Get the positive/negative sentiment for a given word.  Return a HashRef of
+positive/negative keys.  If the word does not exist, return C<undef>.
+
+=head2 nrc_get_word()
+
+  $sentiment = $opinion->nrc_get_word($word);
+
+Get the NRC emotional sentiment for a given word.  Return a HashRef of the NRC
+emotions.  If the word does not exist, return C<undef>.
+
 =head1 SEE ALSO
 
 L<Moo>
